@@ -24,20 +24,21 @@ def pytest_runtest_makereport(item, call):
 
 # report.when value --setup, call, teardown
     if report.when == 'call':
-        if item.funcargs['screenshot_count'] > 0:       # Handle non-breakable but script didn't handle fail case, therefore whole testcase will pass
             # item.module.test_obj.gif_file_name
-            f_name = None
-            if item.config.option.bdd_flag == 'Y':
-                f_name = item.module.test_obj.write_test_summary()
-            elif 'test_obj' in item.funcargs and item.funcargs['test_obj'].gif_file_name:
+        f_name = None
+        if item.config.option.bdd_flag == 'Y':
+            # write_test_summary() will return gif file if any. Also bdd will not run the decorator, therefore will not write_test_summary()
+            f_name = item.module.test_obj.write_test_summary()
+        elif 'test_obj' in item.funcargs and item.funcargs['test_obj'].gif_file_name:
+            if item.funcargs['test_obj'].screenshot_counter > 0:  # Handle non-breakable but script didn't handle fail case, therefore whole testcase will pass
                 f_name = item.funcargs['test_obj'].gif_file_name
-            elif 'test_mobile_obj' in item.funcargs and item.funcargs['test_mobile_obj'].gif_file_name:
+        elif 'test_mobile_obj' in item.funcargs and item.funcargs['test_mobile_obj'].gif_file_name:
+            if item.funcargs['test_mobile_obj'].screenshot_counter > 0:  # Handle non-breakable but script didn't handle fail case, therefore whole testcase will pass
                 f_name = item.funcargs['test_mobile_obj'].gif_file_name
-            if f_name:
-                extra.append(extras.image(f_name, mime_type='image/gif', extension='gif'))
+        if f_name:
+            extra.append(extras.image(f_name, mime_type='image/gif', extension='gif'))
         report.extra = extra
 
-
 @pytest.fixture
 def test_obj(base_url, browser, browser_version, os_version, os_name, remote_flag, testrail_flag, tesults_flag,
              test_run_id, remote_project_name, remote_build_name, testname, reportportal_service, interactivemode_flag,
