@@ -69,9 +69,9 @@ class Wrapit():
                 print("Python says:%s" % str(e))
                 test_obj.write(traceback.format_exc())
                 if test_obj.screenshot != 'off':        # Add for handling fail screenshot *Break case (Take screenshot for non off case)
-                    screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
-                    args[0].screenshot_counter += 1
-                    args[0].save_screenshot(screenshot_name)
+                    screenshot_name = '%003d' % test_obj.screenshot_counter + '_' + func.__name__
+                    test_obj.screenshot_counter += 1
+                    test_obj.save_screenshot(screenshot_name)
 
                 # Detail print in last line
                 with open(test_obj.logs_parent_dir + test_obj.log_name, "a") as logfile:
